Learn R Programming

chcd (version 0.1.1)

stations_near: Finds climate stations near to a given location.

Description

Finds climate stations near to a given location.

Usage

stations_near(longitude, latitude, distance)

Value

A tibble containing the id, name, and locations for all valid stations within the radius of distance from point.

Arguments

longitude

The longitude of the point

latitude

The latitude of the point

distance

The distance in KM from the point to pull in stations